==> bibledit-web-1.4.zip: bibledit-web/setup/tables.php <==
<?php
/*
Copyright (©) 2003-2013 Teus Benschop.

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
*/
?>
<!DOCTYPE html>
<html>
<head>
<meta http-equiv="Content-Type" content="text/html; charset=utf-8" />
<title>Bibledit-Web Installation</title>
<link rel="stylesheet" href="stylesheet.css" type="text/css" />
<script type="text/javascript" src="../jquery/jquery-1.10.2.min.js"></script>
<script type="text/javascript" src="tables.js"></script>
</head>
<body>
<h1><img src="../assets/bibledit.png"> <a href="http://bibledit.org/">Bibledit-Web</a></h1>
<p>Bibledit-Web is evaluating the tables in the database, creating missing ones and upgrading existing ones.</p>
<table class="form-table">
  <tr>
    <th>logs</th>
    <td><img src="../pix/loading.gif"></td>
  </tr>
  <tr>
    <th>users</th>
    <td><img src="../pix/loading.gif"></td>
  </tr>
  <tr>
    <th>config</th>
    <td><img src="../pix/loading.gif"></td>
  </tr>
  <tr>
    <th>mail</th>
    <td><img src="../pix/loading.gif"></td>
  </tr>
  <tr>
    <th>confirm</th>
    <td><img src="../pix/loading.gif"></td>
  </tr>
  <tr>
    <th>books</th>
    <td><img src="../pix/loading.gif"></td>
  </tr>
  <tr>
    <th>versifications</th>
    <td><img src="../pix/loading.gif"></td>
  </tr>
  <tr>
    <th>styles</th>
    <td><img src="../pix/loading.gif"></td>
  </tr>
  <tr>
    <th>bibles</th>
    <td><img src="../pix/loading.gif"></td>
  </tr>
  <tr>
    <th>ipc</th>
    <td><img src="../pix/loading.gif"></td>
  </tr>
  <tr>
    <th>notes</th>
    <td><img src="../pix/loading.gif"></td>
  </tr>
  <tr>
    <th>shell</th>
    <td><img src="../pix/loading.gif"></td>
  </tr>
  <tr>
    <th>check</th>
    <td><img src="../pix/loading.gif"></td>
  </tr>
  <tr>
    <th>resources</th>
    <td><img src="../pix/loading.gif"></td>
  </tr>
  <tr>
    <th>usfmresources</th>
    <td><img src="../pix/loading.gif"></td>
  </tr>
  <tr>
    <th>offlineresources</th>
    <td><img src="../pix/loading.gif"></td>
  </tr>
  <tr>
    <th>consistency</th>
    <td><img src="../pix/loading.gif"></td>
  </tr>
  <tr>
    <th>sprint</th>
    <td><img src="../pix/loading.gif"></td>
  </tr>
  <tr>
    <th>navigation</th>
    <td><img src="../pix/loading.gif"></td>
  </tr>
  <tr>
    <th>history</th>
    <td><img src="../pix/loading.gif"></td>
  </tr>
  <tr>
    <th>commits</th>
    <td><img src="../pix/loading.gif"></td>
  </tr>
  <tr>
    <th>watchdog</th>
    <td><img src="../pix/loading.gif"></td>
  </tr>
  <tr>
    <th>tasks</th>
    <td><img src="../pix/loading.gif"></td>
  </tr>
  <tr>
    <th>jobs</th>
    <td><img src="../pix/loading.gif"></td>
  </tr>
  <tr>
    <th>search</th>
    <td><img src="../pix/loading.gif"></td>
  </tr>
  <tr>
    <th>modifications</th>
    <td><img src="../pix/loading.gif"></td>
  </tr>
</table>
<p id="okay">Congratulations! You have completed this part of the installation.</p>
<p id="progress">All tables are being checked, created, and upgraded.</p>
<p id="fail">Errors occurred. Information for correction or asking help from an expert is being displayed.</p>
<p id="continue"><a href="step.php" class="button button-large">Carry on!</a></p>
<p id="retry"><a href="tables.php" class="button button-large">Retry</a></p>
</body>
</html>

==> bibledit-web-1.5.zip: bibledit-web/setup/tables.php <==
<?php
/*
Copyright (©) 2003-2013 Teus Benschop.

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
*/
?>
<!DOCTYPE html>
<html>
<head>
<meta http-equiv="Content-Type" content="text/html; charset=utf-8" />
<title>Bibledit-Web Installation</title>
<link rel="stylesheet" href="stylesheet.css" type="text/css" />
<script type="text/javascript" src="../jquery/jquery-1.10.2.min.js"></script>
<script type="text/javascript" src="tables.js"></script>
</head>
<body>
<h1><img src="../assets/bibledit.png"> <a href="http://bibledit.org/">Bibledit-Web</a></h1>
<p>Bibledit-Web is evaluating the tables in the database, creating missing ones and upgrading existing ones.</p>
<table class="form-table">
  <tr>
    <th>users</th>
    <td><img src="../pix/loading.gif"></td>
  </tr>
  <tr>
    <th>config</th>
    <td><img src="../pix/loading.gif"></td>
  </tr>
  <tr>
    <th>mail</th>
    <td><img src="../pix/loading.gif"></td>
  </tr>
  <tr>
    <th>confirm</th>
    <td><img src="../pix/loading.gif"></td>
  </tr>
  <tr>
    <th>books</th>
    <td><img src="../pix/loading.gif"></td>
  </tr>
  <tr>
    <th>versifications</th>
    <td><img src="../pix/loading.gif"></td>
  </tr>
  <tr>
    <th>styles</th>
    <td><img src="../pix/loading.gif"></td>
  </tr>
  <tr>
    <th>bibles</th>
    <td><img src="../pix/loading.gif"></td>
  </tr>
  <tr>
    <th>ipc</th>
    <td><img src="../pix/loading.gif"></td>
  </tr>
  <tr>
    <th>notes</th>
    <td><img src="../pix/loading.gif"></td>
  </tr>
  <tr>
    <th>shell</th>
    <td><img src="../pix/loading.gif"></td>
  </tr>
  <tr>
    <th>check</th>
    <td><img src="../pix/loading.gif"></td>
  </tr>
  <tr>
    <th>usfmresources</th>
    <td><img src="../pix/loading.gif"></td>
  </tr>
  <tr>
    <th>volatile</th>
    <td><img src="../pix/loading.gif"></td>
  </tr>
  <tr>
    <th>sprint</th>
    <td><img src="../pix/loading.gif"></td>
  </tr>
  <tr>
    <th>navigation</th>
    <td><img src="../pix/loading.gif"></td>
  </tr>
  <tr>
    <th>history</th>
    <td><img src="../pix/loading.gif"></td>
  </tr>
  <tr>
    <th>commits</th>
    <td><img src="../pix/loading.gif"></td>
  </tr>
  <tr>
    <th>jobs</th>
    <td><img src="../pix/loading.gif"></td>
  </tr>
  <tr>
    <th>search</th>
    <td><img src="../pix/loading.gif"></td>
  </tr>
</table>
<p id="okay">Congratulations! You have completed this part of the installation.</p>
<p id="progress">All tables are being checked, created, and upgraded.</p>
<p id="fail">Errors occurred. Information for correction or asking help from an expert is being displayed.</p>
<p id="continue"><a href="step.php" class="button button-large">Carry on!</a></p>
<p id="retry"><a href="tables.php" class="button button-large">Retry</a></p>
</body>
</html>
